@@ -39,7 +39,7 @@ PARQUET_INCOMPATIBLE = ['json', ]
 OUTPUT_SEPARATORS = {'airr': '\t',
                      'imgt': ',',
                      'tabular': ','}
-OUTPUT_EXTENSIONS = {'airr': '.txt',
+OUTPUT_EXTENSIONS = {'airr': '.tsv',
                      'json': '.json',
                      'imgt': '.csv',
                      'tabular': '.csv'}
@@ -200,7 +200,7 @@ class AbstarResult(object):
                     'n1_nt': self.antibody.junction.n1_nt,
                     'd_nt': self.antibody.junction.d_nt,
                     'n2_nt': self.antibody.junction.n2_nt,
-                    'j_nt': self.antibody.junction.j_nt, #Change from 'self.antibody.junction.v_nt' to 'self.antibody.junction.j_nt'
+                    'j_nt': self.antibody.junction.j_nt,
 #                     'd_cdr3_pos': {'start': self.antibody.junction.d_start_position_nt,
 #                                    'end': self.antibody.junction.d_end_position_nt},
                     'd_dist_from_cdr3_start': self.antibody.junction.d_dist_from_cdr3_start_nt,
@@ -218,7 +218,7 @@ class AbstarResult(object):
         else:
             junc = {'v_nt': self.antibody.junction.v_nt,
                     'n_nt': self.antibody.junction.n_nt,
-                    'j_nt': self.antibody.junction.j_nt} #Change from 'self.antibody.junction.v_nt' to 'self.antibody.junction.j_nt'
+                    'j_nt': self.antibody.junction.j_nt}
 
         output = collections.OrderedDict([
             ('seq_id', self.antibody.id),
@@ -465,6 +465,7 @@ class AbstarResult(object):
             ('umi', self.antibody.uid),
             ('sequence', self.antibody.vdj_nt),
             ('sequence_aa', self.antibody.vdj_aa),
+            ('sequence_input', self.antibody.raw_input.sequence),
             ('rev_comp', 'True' if self.antibody.v.strand == '-' else 'False'),
             ('productive', 'True' if self.antibody.productivity.is_productive else 'False'),
             ('productivity_issues', '|'.join(self.antibody.productivity.productivity_issues)),
@@ -503,6 +504,24 @@ class AbstarResult(object):
             ('junction', self.antibody.junction.junction_nt),
             ('junction_aa', self.antibody.junction.junction_aa),
             ('junction_in_frame', 'True' if self.antibody.junction.in_frame else 'False'),
+            ('junction_v', self.antibody.junction.v_nt),
+            ('junction_d', self.antibody.junction.d_nt),
+            ('junction_j', self.antibody.junction.j_nt),
+            ('junction_n', self.antibody.junction.n_nt),
+            ('junction_n1', self.antibody.junction.n1_nt),
+            ('junction_n2', self.antibody.junction.n2_nt),
+            ('junction_v_aa', self.antibody.junction.v_aa),
+            ('junction_d_aa', self.antibody.junction.d_aa),
+            ('junction_j_aa', self.antibody.junction.j_aa),
+            ('junction_n_aa', self.antibody.junction.n_aa),
+            ('junction_n1_aa', self.antibody.junction.n1_aa),
+            ('junction_n2_aa', self.antibody.junction.n2_aa),
+            ('junction_germ_v', self.antibody.junction.v_germ_nt),
+            ('junction_germ_d', self.antibody.junction.d_germ_nt),
+            ('junction_germ_j', self.antibody.junction.j_germ_nt),
+            ('junction_germ_v_aa', self.antibody.junction.v_germ_aa),
+            ('junction_germ_d_aa', self.antibody.junction.d_germ_aa),
+            ('junction_germ_j_aa', self.antibody.junction.j_germ_aa),
             ('isotype', c_call),
             ('locus', self.antibody.v.gene[:3].upper()),
             ('v_cigar', make_cigar(self.antibody.v)),
@@ -510,9 +529,8 @@ class AbstarResult(object):
             ('j_cigar', make_cigar(self.antibody.j)),
             ('species', self.antibody.species),
             ('germline_database', self.antibody.germ_db),
-            ('raw_input', self.antibody.raw_input.sequence),
         ])
-        return '\t'.join(output.values())
+        return '\t'.join([v if v is not None else '' for v in output.values()])
 
 
 def get_output_suffix(output_format):
@@ -1067,6 +1085,7 @@ AIRR_HEADER = ['sequence_id',
                'umi',
                'sequence',
                'sequence_aa',
+               'sequence_input',
                'rev_comp',
                'productive',
                'productivity_issues',
@@ -1104,14 +1123,31 @@ AIRR_HEADER = ['sequence_id',
                'junction',
                'junction_aa',
                'junction_in_frame',
+               'junction_v',
+               'junction_d',
+               'junction_j',
+               'junction_n',
+               'junction_n1',
+               'junction_n2',
+               'junction_v_aa',
+               'junction_d_aa',
+               'junction_j_aa',
+               'junction_n_aa',
+               'junction_n1_aa',
+               'junction_n2_aa',
+               'junction_germ_v',
+               'junction_germ_d',
+               'junction_germ_j',
+               'junction_germ_v_aa',
+               'junction_germ_d_aa',
+               'junction_germ_j_aa',
                'isotype',
                'locus',
                'v_cigar',
                'd_cigar',
                'j_cigar',
                'species',
-               'germline_database',
-               'raw_input']
+               'germline_database',]
 
 
 
